# dplyr ------------------------------------------------------------------------
#' @export
#' @importFrom dplyr %>%
dplyr::`%>%`


# gtsummary ------------------------------------------------------------------------
#' @export
#' @importFrom gtsummary add_overall
gtsummary::add_overall

#' @export
#' @importFrom gtsummary filter_hierarchical
gtsummary::filter_hierarchical

#' @export
#' @importFrom gtsummary sort_hierarchical
gtsummary::sort_hierarchical

#' @export
#' @importFrom gtsummary add_difference_row
gtsummary::add_difference_row
